# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/ben/cole/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Ben\\Cole\\": "packages/ben/cole/src",
            "Ben\\Cole\\Seeders\\": "packages/ben/cole/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Ben\Cole\Providers\ColeServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Cole'  => Ben\Cole\Facades\Cole::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Ben\\Cole\\Seeders\\ColeTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Ben\Cole\Providers\ColeServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Ben\Cole\Providers\ColeServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Ben\Cole\Providers\ColeServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/cole/{modulename}

**User**

    http://path-to-route-folder/user/cole/{modulename}

**Public**

    http://path-to-route-folder/coles


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/cole/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/cole/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/cole/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/cole/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/cole/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/cole/{modulename}/{slug}
    METHOD: GET